<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Sì',
    'no' => 'No',
    'update' => 'Aggiorna',
    'save' => 'Salva',
    'add' => 'Aggiungi',
    'cancel' => 'Annulla',
    'confirm' => 'Conferma',
    'delete_confirm' => 'Sei sicuro?',
    'delete' => 'Elimina',
    'edit' => 'Modifica',
    'upload' => 'Carica',
    'download' => 'Scarica',
    'save_close' => 'Salva e chiudi',
    'close' => 'Chiudi',
    'copy' => 'Copia',
    'create' => 'Crea',
    'remove' => 'Elimina',
    'revoke' => 'Revoca',
    'done' => 'Fatto',
    'back' => 'Indietro',
    'verify' => 'Verifica',
    'new' => 'nuovo',
    'unknown' => 'Non so',
    'load_more' => 'Carica altro',
    'loading' => 'Caricamento…',
    'with' => 'con',
    'today' => 'oggi',
    'yesterday' => 'ieri',
    'another_day' => 'un altro giorno',
    'date' => 'Data',
    'type' => 'Tipo',
    'zoom' => 'Zoom',
    'upgrade' => 'Effettua l\'upgrade per sbloccare',
    'percent_uploaded' => '{percent}% caricato',
    'retry' => 'Riprova',
    'filter' => 'Filtra la lista',
    'go_back' => 'Torna indietro',
    'file_selected' => 'Un file selezionato…|{count} file selezionati…',

    'application_title' => 'Monica – personal relationship manager',
    'application_description' => 'Monica è uno strumento per gestire le interazioni con i vostri cari, amici e familiari.',
    'application_og_title' => 'Stabilisci relazioni migliori con i tuoi cari. CRM gratuito online per amici e famiglia.',

    'markdown_description' => 'Vuoi formattare il tuo testo? Supportiamo Markdown per grassetto, corsivo, liste, e altro ancora.',
    'markdown_link' => 'Leggi documentazione',

    'header_settings_link' => 'Impostazioni',
    'header_logout_link' => 'Disconnettiti',
    'header_changelog_link' => 'Modifiche di prodotto',

    'main_nav_cta' => 'Aggiungi contatti',
    'main_nav_dashboard' => 'Home',
    'main_nav_family' => 'Contatti',
    'main_nav_journal' => 'Diario',
    'main_nav_activities' => 'Attività',
    'main_nav_tasks' => 'Compiti',

    'footer_remarks' => 'Commenti?',
    'footer_send_email' => 'Inviaci un\'email',
    'footer_privacy' => 'Privacy',
    'footer_release' => 'Note di rilascio',
    'footer_newsletter' => 'Newsletter',
    'footer_source_code' => 'Monica su GitHub',
    'footer_version' => 'Versione: :version',
    'footer_new_version' => 'È disponibile una nuova versione di Monica',

    'footer_modal_version_whats_new' => 'Novità',
    'footer_modal_version_release_away' => 'La tua versione è 1 versione indietro rispetto all\'ultima disponibile. Dovresti aggiornare Monica.|La tua versione è :number versioni indietro rispetto all\'ultima disponibile. Dovresti aggiornare Monica.',

    'breadcrumb_dashboard' => 'Home',
    'breadcrumb_list_contacts' => 'Lista dei contatti',
    'breadcrumb_archived_contacts' => 'Contatti archiviati',
    'breadcrumb_journal' => 'Diario',
    'breadcrumb_settings' => 'Impostazioni',
    'breadcrumb_settings_export' => 'Esporta',
    'breadcrumb_settings_users' => 'Utenti',
    'breadcrumb_settings_users_add' => 'Aggiungi un utente',
    'breadcrumb_settings_subscriptions' => 'Sottoscrizioni',
    'breadcrumb_settings_import' => 'Importa',
    'breadcrumb_settings_import_report' => 'Resoconto dell\'importazione',
    'breadcrumb_settings_import_upload' => 'Carica',
    'breadcrumb_settings_tags' => 'Etichette',
    'breadcrumb_add_significant_other' => 'Aggiungi partner',
    'breadcrumb_edit_significant_other' => 'Modifica partner',
    'breadcrumb_add_note' => 'Aggiungi una nota',
    'breadcrumb_edit_note' => 'Modifica nota',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'Risorse DAV',
    'breadcrumb_edit_introductions' => 'Come vi siete conosciuti',
    'breadcrumb_settings_personalization' => 'Personalizzazione',
    'breadcrumb_settings_security' => 'Sicurezza',
    'breadcrumb_settings_security_2fa' => 'Autenticazione due fattori',
    'breadcrumb_profile' => 'Profilo di :name',

    'gender_male' => 'Uomo',
    'gender_female' => 'Donna',
    'gender_none' => 'Preferisco non specificarlo',
    'gender_no_gender' => 'Nessun genere',

    'error_title' => 'Ops! Qualcosa è andato storto.',
    'error_unauthorized' => 'Non hai il permesso di aggiornare questa risorsa.',
    'error_user_account' => 'Questo utente non appartiene all\'account corrente.',
    'error_save' => 'Abbiamo avuto un errore cercando di salvare i dati.',
    'error_try_again' => 'Qualcosa è andato storto. Riprova.',
    'error_id' => 'ID errore: :id',
    'error_unavailable' => 'Servizio non disponibile',
    'error_maintenance' => 'Manutenzione in corso. Torneremo presto.',
    'error_help' => 'Torneremo presto.',
    'error_twitter' => 'Seguici sul <a href="https://twitter.com/:twitter">nostro account Twitter</a> per venire notificato quando saremo di nuovo online.',
    'error_no_term' => 'Non ci sono ancora regole per questa istanza.',

    'default_save_success' => 'I dati sono stati salvati.',

    'compliance_title' => 'Ci scusiamo per l\'interruzione.',
    'compliance_desc' => 'Abbiamo cambiato i nostri <a href=":urlterm" hreflang=":hreflang">Termini di Utilizzo</a> e <a href=":url" hreflang=":hreflang">Privacy Policy</a>. Per legge dobbiamo chiederti di controllarli e accettarli prima di poter continuare a utilizzare il tuo account.',
    'compliance_desc_end' => 'Non facciamo nulla di losco con i tuoi dati, nè lo faremo mai.',
    'compliance_terms' => 'Accetta i nuovi termini e privacy policy',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Relazioni d\'amore',
    'relationship_type_group_family' => 'Relazioni familiari',
    'relationship_type_group_friend' => 'Rapporti di amicizia',
    'relationship_type_group_work' => 'Rapporti di lavoro',
    'relationship_type_group_other' => 'Altri tipi di relazioni',

    'relationship_type_partner' => 'partner',
    'relationship_type_partner_female' => 'partner',
    'relationship_type_partner_male' => 'partner',
    'relationship_type_partner_with_name' => 'partner di :name',
    'relationship_type_partner_female_with_name' => 'partner di :name',
    'relationship_type_partner_male_with_name' => 'partner di :name',

    'relationship_type_spouse' => 'marito',
    'relationship_type_spouse_female' => 'moglie',
    'relationship_type_spouse_male' => 'marito',
    'relationship_type_spouse_with_name' => 'marito di :name',
    'relationship_type_spouse_female_with_name' => 'Moglie di :name',
    'relationship_type_spouse_male_with_name' => 'Marito di :name',

    'relationship_type_date' => 'impegnato',
    'relationship_type_date_female' => 'impegnata',
    'relationship_type_date_male' => 'data',
    'relationship_type_date_with_name' => 'impegnato con :name',
    'relationship_type_date_female_with_name' => 'impegnata con :name',
    'relationship_type_date_male_with_name' => 'ragazzo di :name',

    'relationship_type_lover' => 'amante',
    'relationship_type_lover_female' => 'amante',
    'relationship_type_lover_male' => 'amante',
    'relationship_type_lover_with_name' => ': nome amante',
    'relationship_type_lover_female_with_name' => ': nome amante',
    'relationship_type_lover_male_with_name' => 'amante di :name',

    'relationship_type_inlovewith' => 'innamorati di',
    'relationship_type_inlovewith_female' => 'innamorati di',
    'relationship_type_inlovewith_male' => 'innamorato di',
    'relationship_type_inlovewith_with_name' => 'qualcuno: è innamorato di',
    'relationship_type_inlovewith_female_with_name' => 'qualcuno di cui :name è innamorata',
    'relationship_type_inlovewith_male_with_name' => 'qualcuno di cui :name è innamorato',

    'relationship_type_lovedby' => 'amato da',
    'relationship_type_lovedby_female' => 'amata da',
    'relationship_type_lovedby_male' => 'amato da',
    'relationship_type_lovedby_with_name' => 'amante segreto di :name',
    'relationship_type_lovedby_female_with_name' => 'amante segreto di :name',
    'relationship_type_lovedby_male_with_name' => 'amante segreto di :name',

    'relationship_type_ex' => 'ex compagno/a',
    'relationship_type_ex_female' => 'ex-fidanzata',
    'relationship_type_ex_male' => 'ex-fidanzato',
    'relationship_type_ex_with_name' => 'Ex compagno/a di :name',
    'relationship_type_ex_female_with_name' => 'ex-fidanzata di :name',
    'relationship_type_ex_male_with_name' => 'Ex fidanzato di :name',

    'relationship_type_parent' => 'genitore',
    'relationship_type_parent_female' => 'madre',
    'relationship_type_parent_male' => 'padre',
    'relationship_type_parent_with_name' => 'Genitore di :name',
    'relationship_type_parent_female_with_name' => 'madre di :name',
    'relationship_type_parent_male_with_name' => 'Padre di :name',

    'relationship_type_child' => 'bambino/a',
    'relationship_type_child_female' => 'figlia',
    'relationship_type_child_male' => 'figlio',
    'relationship_type_child_with_name' => 'Bambino/a di :name',
    'relationship_type_child_female_with_name' => 'figlia di :name',
    'relationship_type_child_male_with_name' => 'Figlio di :name',

    'relationship_type_stepparent' => 'genitore adottivo',
    'relationship_type_stepparent_female' => 'madrigna',
    'relationship_type_stepparent_male' => 'padre adottivo',
    'relationship_type_stepparent_with_name' => 'Genitore adottivo di :name',
    'relationship_type_stepparent_female_with_name' => ':name della matrigna',
    'relationship_type_stepparent_male_with_name' => 'Padre adottivo di :name',

    'relationship_type_stepchild' => 'figlio/a adottivo',
    'relationship_type_stepchild_female' => 'figliastra',
    'relationship_type_stepchild_male' => 'figlio adottivo',
    'relationship_type_stepchild_with_name' => 'Figlio/a adottivo/a di :name',
    'relationship_type_stepchild_female_with_name' => ':name della figliastra',
    'relationship_type_stepchild_male_with_name' => 'Figlio adottivo di :name',

    'relationship_type_sibling' => 'fratello/sorella',
    'relationship_type_sibling_female' => 'sorella',
    'relationship_type_sibling_male' => 'fratello',
    'relationship_type_sibling_with_name' => 'Fratello/Sorella di :name',
    'relationship_type_sibling_female_with_name' => 'sorella di :name',
    'relationship_type_sibling_male_with_name' => 'Fratello di :name',

    'relationship_type_grandparent' => 'nonno/a',
    'relationship_type_grandparent_female' => 'nonna',
    'relationship_type_grandparent_male' => 'nonno',
    'relationship_type_grandparent_with_name' => 'Nonno/a di :name',
    'relationship_type_grandparent_female_with_name' => 'Nonna di :name',
    'relationship_type_grandparent_male_with_name' => 'Nonno di :name',

    'relationship_type_grandchild' => 'nipote',
    'relationship_type_grandchild_female' => 'nipote',
    'relationship_type_grandchild_male' => 'nipote',
    'relationship_type_grandchild_with_name' => 'Nipote di :name',
    'relationship_type_grandchild_female_with_name' => 'Nipotina di :name',
    'relationship_type_grandchild_male_with_name' => 'Nipotino di :name',

    'relationship_type_uncle' => 'zio',
    'relationship_type_uncle_female' => 'zia',
    'relationship_type_uncle_male' => 'zio',
    'relationship_type_uncle_with_name' => 'zio di :name',
    'relationship_type_uncle_female_with_name' => 'zia di :name',
    'relationship_type_uncle_male_with_name' => 'zio di :name',

    'relationship_type_nephew' => 'nipote',
    'relationship_type_nephew_female' => 'nipote',
    'relationship_type_nephew_male' => 'nipote',
    'relationship_type_nephew_with_name' => 'nipote di :name',
    'relationship_type_nephew_female_with_name' => 'nipote di :name',
    'relationship_type_nephew_male_with_name' => 'nipote di :name',

    'relationship_type_cousin' => 'cugino',
    'relationship_type_cousin_female' => 'cugino',
    'relationship_type_cousin_male' => 'cugino',
    'relationship_type_cousin_with_name' => 'Cugino di :name',
    'relationship_type_cousin_female_with_name' => 'Cugina di :name',
    'relationship_type_cousin_male_with_name' => 'cugino di :name',

    'relationship_type_godfather' => 'padrino',
    'relationship_type_godfather_female' => 'madrina',
    'relationship_type_godfather_male' => 'padrino',
    'relationship_type_godfather_with_name' => 'Padrino/Madrina di :name',
    'relationship_type_godfather_female_with_name' => ': nome della madrina',
    'relationship_type_godfather_male_with_name' => 'Padrino di :name',

    'relationship_type_godson' => 'figlioccio/a',
    'relationship_type_godson_female' => 'figlioccia',
    'relationship_type_godson_male' => 'figlioccio',
    'relationship_type_godson_with_name' => 'Figlioccio/a di :name',
    'relationship_type_godson_female_with_name' => 'figlioccia di :name',
    'relationship_type_godson_male_with_name' => 'Figlioccio di :name',

    'relationship_type_friend' => 'amico',
    'relationship_type_friend_female' => 'amico',
    'relationship_type_friend_male' => 'amico',
    'relationship_type_friend_with_name' => 'amico di :name',
    'relationship_type_friend_female_with_name' => 'amica di :name',
    'relationship_type_friend_male_with_name' => 'amico di :name',

    'relationship_type_bestfriend' => 'miglior amico',
    'relationship_type_bestfriend_female' => 'miglior amico',
    'relationship_type_bestfriend_male' => 'migliore amico',
    'relationship_type_bestfriend_with_name' => 'miglior amico di :name',
    'relationship_type_bestfriend_female_with_name' => 'miglior amica di :name',
    'relationship_type_bestfriend_male_with_name' => 'migliore amico di :name',

    'relationship_type_colleague' => 'collega',
    'relationship_type_colleague_female' => 'collega',
    'relationship_type_colleague_male' => 'collega',
    'relationship_type_colleague_with_name' => 'collega di :name',
    'relationship_type_colleague_female_with_name' => 'collega di :name',
    'relationship_type_colleague_male_with_name' => 'collega di :name',

    'relationship_type_boss' => 'capo',
    'relationship_type_boss_female' => 'capo',
    'relationship_type_boss_male' => 'capo',
    'relationship_type_boss_with_name' => 'capo di :name',
    'relationship_type_boss_female_with_name' => 'capo di :name',
    'relationship_type_boss_male_with_name' => 'capo di :name',

    'relationship_type_subordinate' => 'dipendente',
    'relationship_type_subordinate_female' => 'dipendente',
    'relationship_type_subordinate_male' => 'subordinate',
    'relationship_type_subordinate_with_name' => 'dipendente di :name',
    'relationship_type_subordinate_female_with_name' => 'dipendente di :name',
    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',

    'relationship_type_mentor' => 'mentore',
    'relationship_type_mentor_female' => 'mentrice',
    'relationship_type_mentor_male' => 'mentore',
    'relationship_type_mentor_with_name' => 'mentore di :name',
    'relationship_type_mentor_female_with_name' => 'mentrice di :name',
    'relationship_type_mentor_male_with_name' => 'mentore di :name',

    'relationship_type_protege' => 'protetto',
    'relationship_type_protege_female' => 'protetta',
    'relationship_type_protege_male' => 'protégé',
    'relationship_type_protege_with_name' => 'Protetto di :name',
    'relationship_type_protege_female_with_name' => 'Protetta di :name',
    'relationship_type_protege_male_with_name' => ':name’s protégé',

    'relationship_type_ex_husband' => 'ex coniuge',
    'relationship_type_ex_husband_female' => 'ex moglie',
    'relationship_type_ex_husband_male' => 'ex marito',
    'relationship_type_ex_husband_with_name' => 'Ex coniuge di :name',
    'relationship_type_ex_husband_female_with_name' => 'ex moglie di :name',
    'relationship_type_ex_husband_male_with_name' => 'Ex marito di :name',

    // emotions
    'emotion_primary_love' => 'Amore',
    'emotion_primary_joy' => 'Felicità',
    'emotion_primary_surprise' => 'Sorpresa',
    'emotion_primary_anger' => 'Rabbia',
    'emotion_primary_sadness' => 'Tristezza',
    'emotion_primary_fear' => 'Paura',

    'emotion_secondary_affection' => 'Affetto',
    'emotion_secondary_lust' => 'Lussuria',
    'emotion_secondary_longing' => 'Bramosia',
    'emotion_secondary_cheerfulness' => 'Allegria',
    'emotion_secondary_zest' => 'Gusto',
    'emotion_secondary_contentment' => 'Soddisfazione',
    'emotion_secondary_pride' => 'Orgoglio',
    'emotion_secondary_optimism' => 'Ottimismo',
    'emotion_secondary_enthrallment' => 'Fascino',
    'emotion_secondary_relief' => 'Sollievo',
    'emotion_secondary_surprise' => 'Sorpresa',
    'emotion_secondary_irritation' => 'Irritazione',
    'emotion_secondary_exasperation' => 'Esasperazione',
    'emotion_secondary_rage' => 'Rabbia',
    'emotion_secondary_disgust' => 'Disgusto',
    'emotion_secondary_envy' => 'Invidia',
    'emotion_secondary_suffering' => 'Sofferenza',
    'emotion_secondary_sadness' => 'Tristezza',
    'emotion_secondary_disappointment' => 'Disappunto',
    'emotion_secondary_shame' => 'Vergogna',
    'emotion_secondary_neglect' => 'Negligenza',
    'emotion_secondary_sympathy' => 'Simpatia',
    'emotion_secondary_horror' => 'Orrore',
    'emotion_secondary_nervousness' => 'Nervosismo',

    'emotion_adoration' => 'Adorazione',
    'emotion_affection' => 'Affetto',
    'emotion_love' => 'Amore',
    'emotion_fondness' => 'Passione',
    'emotion_liking' => 'Simpatia',
    'emotion_attraction' => 'Attrazione',
    'emotion_caring' => 'Cura',
    'emotion_tenderness' => 'Tenerezza',
    'emotion_compassion' => 'Compassione',
    'emotion_sentimentality' => 'Sentimentalità',
    'emotion_arousal' => 'Eccitazione',
    'emotion_desire' => 'Desiderio',
    'emotion_lust' => 'Lussuria',
    'emotion_passion' => 'Passione',
    'emotion_infatuation' => 'Infatuazione',
    'emotion_longing' => 'Bramosia',
    'emotion_amusement' => 'Divertimento',
    'emotion_bliss' => 'Beatitudine',
    'emotion_cheerfulness' => 'Allegria',
    'emotion_gaiety' => 'Giocondità',
    'emotion_glee' => 'Gioia',
    'emotion_jolliness' => 'Gaietà',
    'emotion_joviality' => 'Giovialità',
    'emotion_joy' => 'Felicità',
    'emotion_delight' => 'Delizia',
    'emotion_enjoyment' => 'Godimento',
    'emotion_gladness' => 'Contentezza',
    'emotion_happiness' => 'Felicità',
    'emotion_jubilation' => 'Esultanza',
    'emotion_elation' => 'Esaltazione',
    'emotion_satisfaction' => 'Soddisfazione',
    'emotion_ecstasy' => 'Estasi',
    'emotion_euphoria' => 'Euforia',
    'emotion_enthusiasm' => 'Entusiasmo',
    'emotion_zeal' => 'Zelo',
    'emotion_zest' => 'Gusto',
    'emotion_excitement' => 'Eccitamento',
    'emotion_thrill' => 'Fremito',
    'emotion_exhilaration' => 'Esilarante',
    'emotion_contentment' => 'Appagamento',
    'emotion_pleasure' => 'Piacere',
    'emotion_pride' => 'Orgoglio',
    'emotion_eagerness' => 'Impazienza',
    'emotion_hope' => 'Speranza',
    'emotion_optimism' => 'Ottimismo',
    'emotion_enthrallment' => 'Divertimento',
    'emotion_rapture' => 'Estasi',
    'emotion_relief' => 'Sollievo',
    'emotion_amazement' => 'Stupore',
    'emotion_surprise' => 'Sorpresa',
    'emotion_astonishment' => 'Stupefacente',
    'emotion_aggravation' => 'Peggioramento',
    'emotion_irritation' => 'Irritazione',
    'emotion_agitation' => 'Agitazione',
    'emotion_annoyance' => 'Fastidio',
    'emotion_grouchiness' => 'Cattivo umore',
    'emotion_grumpiness' => 'Irritabilità',
    'emotion_exasperation' => 'Esasperazione',
    'emotion_frustration' => 'Frustrazione',
    'emotion_anger' => 'Rabbia',
    'emotion_rage' => 'Collera',
    'emotion_outrage' => 'Oltraggio',
    'emotion_fury' => 'Furia',
    'emotion_wrath' => 'Ira',
    'emotion_hostility' => 'Ostilità',
    'emotion_ferocity' => 'Ferocità',
    'emotion_bitterness' => 'Amarezza',
    'emotion_hate' => 'Odio',
    'emotion_loathing' => 'Ripugnanza',
    'emotion_scorn' => 'Disprezzo',
    'emotion_spite' => 'Rancore',
    'emotion_vengefulness' => 'Vendicatività',
    'emotion_dislike' => 'Antipatia',
    'emotion_resentment' => 'Risentimento',
    'emotion_disgust' => 'Disgusto',
    'emotion_revulsion' => 'Repulsione',
    'emotion_contempt' => 'Disprezzo',
    'emotion_envy' => 'Invidia',
    'emotion_jealousy' => 'Gelosia',
    'emotion_agony' => 'Agonia',
    'emotion_suffering' => 'Sofferenza',
    'emotion_hurt' => 'Dolore',
    'emotion_anguish' => 'Angoscia',
    'emotion_depression' => 'Depressione',
    'emotion_despair' => 'Disperazione',
    'emotion_hopelessness' => 'Senza speranza',
    'emotion_gloom' => 'Maliconia',
    'emotion_glumness' => 'Cupezza',
    'emotion_sadness' => 'Tristezza',
    'emotion_unhappiness' => 'Infelicità',
    'emotion_grief' => 'Afflizione',
    'emotion_sorrow' => 'Pena',
    'emotion_woe' => 'Calamità',
    'emotion_misery' => 'Miseria',
    'emotion_melancholy' => 'Malinconia',
    'emotion_dismay' => 'Sgomento',
    'emotion_disappointment' => 'Disappunto',
    'emotion_displeasure' => 'Scontento',
    'emotion_guilt' => 'Colpevolezza',
    'emotion_shame' => 'Vergogna',
    'emotion_regret' => 'Rimpianto',
    'emotion_remorse' => 'Rimorso',
    'emotion_alienation' => 'Alienazione',
    'emotion_isolation' => 'Isolamento',
    'emotion_neglect' => 'Negligenza',
    'emotion_loneliness' => 'Solitudine',
    'emotion_rejection' => 'Rifiuto',
    'emotion_homesickness' => 'Nostalgia',
    'emotion_defeat' => 'Sconfitta',
    'emotion_dejection' => 'Sconforto',
    'emotion_insecurity' => 'Insicurezza',
    'emotion_embarrassment' => 'Imbarazzo',
    'emotion_humiliation' => 'Umiliazione',
    'emotion_insult' => 'Insulto',
    'emotion_pity' => 'Peccato',
    'emotion_sympathy' => 'Simpatia',
    'emotion_alarm' => 'Allarme',
    'emotion_shock' => 'Shock',
    'emotion_fear' => 'Paura',
    'emotion_fright' => 'Spavento',
    'emotion_horror' => 'Orrore',
    'emotion_terror' => 'Terrore',
    'emotion_panic' => 'Panico',
    'emotion_hysteria' => 'Isteria',
    'emotion_mortification' => 'Mortificazione',
    'emotion_anxiety' => 'Ansia',
    'emotion_nervousness' => 'Nervosismo',
    'emotion_tenseness' => 'Tensione',
    'emotion_uneasiness' => 'Disagio',
    'emotion_apprehension' => 'Apprensione',
    'emotion_worry' => 'Preoccupazione',
    'emotion_distress' => 'Angoscia',
    'emotion_dread' => 'Terrore',

    // weather
    'weather_sunny' => 'Soleggiato',
    'weather_clear' => 'Chiaro',
    'weather_clear-day' => 'Chiara',
    'weather_clear-night' => 'Notte limpida',
    'weather_light-drizzle' => 'Pioggia leggera',
    'weather_patchy-light-drizzle' => 'Pioggerellina irregolare',
    'weather_patchy-light-rain' => 'Pioggia leggera e irregolare',
    'weather_light-rain' => 'Pioggia leggera',
    'weather_moderate-rain-at-times' => 'Pioggia moderata e intermittente',
    'weather_moderate-rain' => 'Pioggia moderata',
    'weather_patchy-rain-possible' => 'Possibile pioggia a tratti',
    'weather_heavy-rain-at-times' => 'Forte pioggia intermittente',
    'weather_heavy-rain' => 'Forte pioggia',
    'weather_light-freezing-rain' => 'Light freezing rain',
    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
    'weather_light-sleet' => 'Light sleet',
    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
    'weather_light-rain-shower' => 'Light rain shower',
    'weather_torrential-rain-shower' => 'Torrential rain shower',
    'weather_rain' => 'Pioggia',
    'weather_snow' => 'Neve',
    'weather_blowing-snow' => 'Blowing snow',
    'weather_patchy-light-snow' => 'Patchy light snow',
    'weather_light-snow' => 'Light snow',
    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
    'weather_moderate-snow' => 'Moderate snow',
    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
    'weather_heavy-snow' => 'Forte nevicata',
    'weather_light-snow-showers' => 'Nevicate leggere',
    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
    'weather_patchy-snow-possible' => 'Patchy snow possible',
    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
    'weather_light-sleet-showers' => 'Light sleet showers',
    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
    'weather_sleet' => 'Nevischio',
    'weather_wind' => 'Vento',
    'weather_fog' => 'Nebbia',
    'weather_freezing-fog' => 'Freezing fog',
    'weather_mist' => 'Mist',
    'weather_blizzard' => 'Blizzard',
    'weather_overcast' => 'Overcast',
    'weather_cloudy' => 'Nuvoloso',
    'weather_partly-cloudy-day' => 'Parzialmente nuvoloso',
    'weather_partly-cloudy-night' => 'Parzialmente nuvolosa',
    'weather_freezing-drizzle' => 'Freezing drizzle',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Ice pellets',
    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Meteo attuale',

    // dav
    'dav_contacts' => 'Contatti',
    'dav_contacts_description' => 'contatti di :name',
    'dav_birthdays' => 'Compleanni',
    'dav_birthdays_description' => 'compleanno del contatto di :name',
    'dav_tasks' => 'Compiti',
    'dav_tasks_description' => 'attività di :name',

    // contact list
    'contact_list_avatar' => 'Avatar',
    'contact_list_name' => 'Contatto',
    'contact_list_description' => 'Descrizione',

];
